pywr.parameters.MaxParameter
============================

.. currentmodule:: pywr.parameters

.. autoclass:: MaxParameter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MaxParameter.after
      ~MaxParameter.before
      ~MaxParameter.finish
      ~MaxParameter.get_all_values
      ~MaxParameter.get_double_lower_bounds
      ~MaxParameter.get_double_upper_bounds
      ~MaxParameter.get_double_variables
      ~MaxParameter.get_integer_lower_bounds
      ~MaxParameter.get_integer_upper_bounds
      ~MaxParameter.get_integer_variables
      ~MaxParameter.get_value
      ~MaxParameter.load
      ~MaxParameter.lower_bounds
      ~MaxParameter.register
      ~MaxParameter.reset
      ~MaxParameter.set_double_variables
      ~MaxParameter.set_integer_variables
      ~MaxParameter.setup
      ~MaxParameter.unregister
      ~MaxParameter.update
      ~MaxParameter.upper_bounds
      ~MaxParameter.value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~MaxParameter.children
      ~MaxParameter.comment
      ~MaxParameter.double_size
      ~MaxParameter.integer_size
      ~MaxParameter.is_variable
      ~MaxParameter.model
      ~MaxParameter.name
      ~MaxParameter.parameter
      ~MaxParameter.parents
      ~MaxParameter.size
      ~MaxParameter.threshold
   
   